.. _Python: https://www.python.org/
.. _colorlog: https://github.com/borntyping/python-colorlog

================
Project composer
================

A system to compose project parts from applications enabled in a manifest.


Dependancies
************

* `Python`_>=3.8;
* `colorlog`_ (optional);


Links
*****

* Read the documentation on `Read the docs <https://project-composer.readthedocs.io/>`_;
* Download its `PyPi package <https://pypi.python.org/pypi/project-composer>`_;
* Clone it on its `Github repository <https://github.com/sveetch/project-composer>`_;
